==> Telethon-0.5.0.2-py3-none-any.whl: telethon/tl/functions/messages/__init__.py <==
from telethon.tl.functions.messages.get_messages import GetMessagesRequest
from telethon.tl.functions.messages.get_dialogs import GetDialogsRequest
from telethon.tl.functions.messages.get_history import GetHistoryRequest
from telethon.tl.functions.messages.search import SearchRequest
from telethon.tl.functions.messages.read_history import ReadHistoryRequest
from telethon.tl.functions.messages.delete_history import DeleteHistoryRequest
from telethon.tl.functions.messages.delete_messages import DeleteMessagesRequest
from telethon.tl.functions.messages.received_messages import ReceivedMessagesRequest
from telethon.tl.functions.messages.set_typing import SetTypingRequest
from telethon.tl.functions.messages.send_message import SendMessageRequest
from telethon.tl.functions.messages.send_media import SendMediaRequest
from telethon.tl.functions.messages.forward_messages import ForwardMessagesRequest
from telethon.tl.functions.messages.report_spam import ReportSpamRequest
from telethon.tl.functions.messages.hide_report_spam import HideReportSpamRequest
from telethon.tl.functions.messages.get_peer_settings import GetPeerSettingsRequest
from telethon.tl.functions.messages.get_chats import GetChatsRequest
from telethon.tl.functions.messages.get_full_chat import GetFullChatRequest
from telethon.tl.functions.messages.edit_chat_title import EditChatTitleRequest
from telethon.tl.functions.messages.edit_chat_photo import EditChatPhotoRequest
from telethon.tl.functions.messages.add_chat_user import AddChatUserRequest
from telethon.tl.functions.messages.delete_chat_user import DeleteChatUserRequest
from telethon.tl.functions.messages.create_chat import CreateChatRequest
from telethon.tl.functions.messages.forward_message import ForwardMessageRequest
from telethon.tl.functions.messages.get_dh_config import GetDhConfigRequest
from telethon.tl.functions.messages.request_encryption import RequestEncryptionRequest
from telethon.tl.functions.messages.accept_encryption import AcceptEncryptionRequest
from telethon.tl.functions.messages.discard_encryption import DiscardEncryptionRequest
from telethon.tl.functions.messages.set_encrypted_typing import SetEncryptedTypingRequest
from telethon.tl.functions.messages.read_encrypted_history import ReadEncryptedHistoryRequest
from telethon.tl.functions.messages.send_encrypted import SendEncryptedRequest
from telethon.tl.functions.messages.send_encrypted_file import SendEncryptedFileRequest
from telethon.tl.functions.messages.send_encrypted_service import SendEncryptedServiceRequest
from telethon.tl.functions.messages.received_queue import ReceivedQueueRequest
from telethon.tl.functions.messages.read_message_contents import ReadMessageContentsRequest
from telethon.tl.functions.messages.get_stickers import GetStickersRequest
from telethon.tl.functions.messages.get_all_stickers import GetAllStickersRequest
from telethon.tl.functions.messages.get_web_page_preview import GetWebPagePreviewRequest
from telethon.tl.functions.messages.export_chat_invite import ExportChatInviteRequest
from telethon.tl.functions.messages.check_chat_invite import CheckChatInviteRequest
from telethon.tl.functions.messages.import_chat_invite import ImportChatInviteRequest
from telethon.tl.functions.messages.get_sticker_set import GetStickerSetRequest
from telethon.tl.functions.messages.install_sticker_set import InstallStickerSetRequest
from telethon.tl.functions.messages.uninstall_sticker_set import UninstallStickerSetRequest
from telethon.tl.functions.messages.start_bot import StartBotRequest
from telethon.tl.functions.messages.get_messages_views import GetMessagesViewsRequest
from telethon.tl.functions.messages.toggle_chat_admins import ToggleChatAdminsRequest
from telethon.tl.functions.messages.edit_chat_admin import EditChatAdminRequest
from telethon.tl.functions.messages.migrate_chat import MigrateChatRequest
from telethon.tl.functions.messages.search_global import SearchGlobalRequest
from telethon.tl.functions.messages.reorder_sticker_sets import ReorderStickerSetsRequest
from telethon.tl.functions.messages.get_document_by_hash import GetDocumentByHashRequest
from telethon.tl.functions.messages.search_gifs import SearchGifsRequest
from telethon.tl.functions.messages.get_saved_gifs import GetSavedGifsRequest
from telethon.tl.functions.messages.save_gif import SaveGifRequest
from telethon.tl.functions.messages.get_inline_bot_results import GetInlineBotResultsRequest
from telethon.tl.functions.messages.set_inline_bot_results import SetInlineBotResultsRequest
from telethon.tl.functions.messages.send_inline_bot_result import SendInlineBotResultRequest
from telethon.tl.functions.messages.get_message_edit_data import GetMessageEditDataRequest
from telethon.tl.functions.messages.edit_message import EditMessageRequest
from telethon.tl.functions.messages.edit_inline_bot_message import EditInlineBotMessageRequest
from telethon.tl.functions.messages.get_bot_callback_answer import GetBotCallbackAnswerRequest
from telethon.tl.functions.messages.set_bot_callback_answer import SetBotCallbackAnswerRequest
from telethon.tl.functions.messages.get_peer_dialogs import GetPeerDialogsRequest
from telethon.tl.functions.messages.save_draft import SaveDraftRequest
from telethon.tl.functions.messages.get_all_drafts import GetAllDraftsRequest
from telethon.tl.functions.messages.get_featured_stickers import GetFeaturedStickersRequest
from telethon.tl.functions.messages.read_featured_stickers import ReadFeaturedStickersRequest
from telethon.tl.functions.messages.get_recent_stickers import GetRecentStickersRequest
from telethon.tl.functions.messages.save_recent_sticker import SaveRecentStickerRequest
from telethon.tl.functions.messages.clear_recent_stickers import ClearRecentStickersRequest
from telethon.tl.functions.messages.get_unused_stickers import GetUnusedStickersRequest
from telethon.tl.functions.messages.get_archived_stickers import GetArchivedStickersRequest

==> Telethon-0.9-py3-none-any.whl: telethon/tl/functions/messages/__init__.py <==
from telethon.tl.functions.messages.get_messages import GetMessagesRequest
from telethon.tl.functions.messages.get_dialogs import GetDialogsRequest
from telethon.tl.functions.messages.get_history import GetHistoryRequest
from telethon.tl.functions.messages.search import SearchRequest
from telethon.tl.functions.messages.read_history import ReadHistoryRequest
from telethon.tl.functions.messages.delete_history import DeleteHistoryRequest
from telethon.tl.functions.messages.delete_messages import DeleteMessagesRequest
from telethon.tl.functions.messages.received_messages import ReceivedMessagesRequest
from telethon.tl.functions.messages.set_typing import SetTypingRequest
from telethon.tl.functions.messages.send_message import SendMessageRequest
from telethon.tl.functions.messages.send_media import SendMediaRequest
from telethon.tl.functions.messages.forward_messages import ForwardMessagesRequest
from telethon.tl.functions.messages.report_spam import ReportSpamRequest
from telethon.tl.functions.messages.hide_report_spam import HideReportSpamRequest
from telethon.tl.functions.messages.get_peer_settings import GetPeerSettingsRequest
from telethon.tl.functions.messages.get_chats import GetChatsRequest
from telethon.tl.functions.messages.get_full_chat import GetFullChatRequest
from telethon.tl.functions.messages.edit_chat_title import EditChatTitleRequest
from telethon.tl.functions.messages.edit_chat_photo import EditChatPhotoRequest
from telethon.tl.functions.messages.add_chat_user import AddChatUserRequest
from telethon.tl.functions.messages.delete_chat_user import DeleteChatUserRequest
from telethon.tl.functions.messages.create_chat import CreateChatRequest
from telethon.tl.functions.messages.forward_message import ForwardMessageRequest
from telethon.tl.functions.messages.get_dh_config import GetDhConfigRequest
from telethon.tl.functions.messages.request_encryption import RequestEncryptionRequest
from telethon.tl.functions.messages.accept_encryption import AcceptEncryptionRequest
from telethon.tl.functions.messages.discard_encryption import DiscardEncryptionRequest
from telethon.tl.functions.messages.set_encrypted_typing import SetEncryptedTypingRequest
from telethon.tl.functions.messages.read_encrypted_history import ReadEncryptedHistoryRequest
from telethon.tl.functions.messages.send_encrypted import SendEncryptedRequest
from telethon.tl.functions.messages.send_encrypted_file import SendEncryptedFileRequest
from telethon.tl.functions.messages.send_encrypted_service import SendEncryptedServiceRequest
from telethon.tl.functions.messages.received_queue import ReceivedQueueRequest
from telethon.tl.functions.messages.report_encrypted_spam import ReportEncryptedSpamRequest
from telethon.tl.functions.messages.read_message_contents import ReadMessageContentsRequest
from telethon.tl.functions.messages.get_all_stickers import GetAllStickersRequest
from telethon.tl.functions.messages.get_web_page_preview import GetWebPagePreviewRequest
from telethon.tl.functions.messages.export_chat_invite import ExportChatInviteRequest
from telethon.tl.functions.messages.check_chat_invite import CheckChatInviteRequest
from telethon.tl.functions.messages.import_chat_invite import ImportChatInviteRequest
from telethon.tl.functions.messages.get_sticker_set import GetStickerSetRequest
from telethon.tl.functions.messages.install_sticker_set import InstallStickerSetRequest
from telethon.tl.functions.messages.uninstall_sticker_set import UninstallStickerSetRequest
from telethon.tl.functions.messages.start_bot import StartBotRequest
from telethon.tl.functions.messages.get_messages_views import GetMessagesViewsRequest
from telethon.tl.functions.messages.toggle_chat_admins import ToggleChatAdminsRequest
from telethon.tl.functions.messages.edit_chat_admin import EditChatAdminRequest
from telethon.tl.functions.messages.migrate_chat import MigrateChatRequest
from telethon.tl.functions.messages.search_global import SearchGlobalRequest
from telethon.tl.functions.messages.reorder_sticker_sets import ReorderStickerSetsRequest
from telethon.tl.functions.messages.get_document_by_hash import GetDocumentByHashRequest
from telethon.tl.functions.messages.search_gifs import SearchGifsRequest
from telethon.tl.functions.messages.get_saved_gifs import GetSavedGifsRequest
from telethon.tl.functions.messages.save_gif import SaveGifRequest
from telethon.tl.functions.messages.get_inline_bot_results import GetInlineBotResultsRequest
from telethon.tl.functions.messages.set_inline_bot_results import SetInlineBotResultsRequest
from telethon.tl.functions.messages.send_inline_bot_result import SendInlineBotResultRequest
from telethon.tl.functions.messages.get_message_edit_data import GetMessageEditDataRequest
from telethon.tl.functions.messages.edit_message import EditMessageRequest
from telethon.tl.functions.messages.edit_inline_bot_message import EditInlineBotMessageRequest
from telethon.tl.functions.messages.get_bot_callback_answer import GetBotCallbackAnswerRequest
from telethon.tl.functions.messages.set_bot_callback_answer import SetBotCallbackAnswerRequest
from telethon.tl.functions.messages.get_peer_dialogs import GetPeerDialogsRequest
from telethon.tl.functions.messages.save_draft import SaveDraftRequest
from telethon.tl.functions.messages.get_all_drafts import GetAllDraftsRequest
from telethon.tl.functions.messages.get_featured_stickers import GetFeaturedStickersRequest
from telethon.tl.functions.messages.read_featured_stickers import ReadFeaturedStickersRequest
from telethon.tl.functions.messages.get_recent_stickers import GetRecentStickersRequest
from telethon.tl.functions.messages.save_recent_sticker import SaveRecentStickerRequest
from telethon.tl.functions.messages.clear_recent_stickers import ClearRecentStickersRequest
from telethon.tl.functions.messages.get_archived_stickers import GetArchivedStickersRequest
from telethon.tl.functions.messages.get_mask_stickers import GetMaskStickersRequest
from telethon.tl.functions.messages.get_attached_stickers import GetAttachedStickersRequest
from telethon.tl.functions.messages.set_game_score import SetGameScoreRequest
from telethon.tl.functions.messages.set_inline_game_score import SetInlineGameScoreRequest
from telethon.tl.functions.messages.get_game_high_scores import GetGameHighScoresRequest
from telethon.tl.functions.messages.get_inline_game_high_scores import GetInlineGameHighScoresRequest
from telethon.tl.functions.messages.get_common_chats import GetCommonChatsRequest
from telethon.tl.functions.messages.get_all_chats import GetAllChatsRequest
from telethon.tl.functions.messages.get_web_page import GetWebPageRequest
from telethon.tl.functions.messages.toggle_dialog_pin import ToggleDialogPinRequest
from telethon.tl.functions.messages.reorder_pinned_dialogs import ReorderPinnedDialogsRequest
from telethon.tl.functions.messages.get_pinned_dialogs import GetPinnedDialogsRequest
from telethon.tl.functions.messages.set_bot_shipping_results import SetBotShippingResultsRequest
from telethon.tl.functions.messages.set_bot_precheckout_results import SetBotPrecheckoutResultsRequest
